==> webgui_7.6.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_RichEdit.pm <==
package WebGUI::i18n::English::Asset_RichEdit;
use strict;

our $I18N = {

	'toolbar buttons' => {
		message => q|Toolbar Buttons|,
        	lastUpdated => 1115139736,
	},

	'toolbar buttons description' => {
		message => q|Shows which toolbar buttons will be used in which toolbars in the editor.  To remove a toolbar, deselect all buttons in that toolbar's column.  Note that other fields may add buttons to a toolbar row as well, such as Enable Context Menu.  Adding buttons also may not enable functionality.  You may also need to update the Valid Elements for this editor.|,
        	lastUpdated => 1228332284,
	},

	'using rich edit' => {
		message => q|Ask user about using rich edit?|,
        	lastUpdated => 1115139819,
	},

	'preformatted' => {
		message => q|Preserve whitespace as preformatted text?|,
        	lastUpdated => 1115139859,
	},

	'elements' => {
		message => q|Valid Elements|,
        	lastUpdated => 1115148094,
	},

	'elements subtext' => {
		message => q|<br /> Must appear on one line, no carriage returns, and in the format of tag1[attr1\|attr2],tag2[attr1].|,
        	lastUpdated => 1115148094,
	},

	'editor height' => {
		message => q|Editor Height|,
        	lastUpdated => 1115148094,
	},

	'editor width' => {
		message => q|Editor Width|,
        	lastUpdated => 1115148094,
	},

	'source editor height' => {
		message => q|Source Editor Height|,
        	lastUpdated => 1115148094,
	},

	'source editor width' => {
		message => q|Source Editor Width|,
        	lastUpdated => 1115148094,
	},

	'use br' => {
		message => q|Use &lt;br /&gt; instead of &lt;p&gt; on 'Enter'?|,
        	lastUpdated => 1115148632,
	},

	'remove line breaks' => {
		message => q|Remove line breaks from HTML?|,
        	lastUpdated => 1115148632,
	},

	'no wrap' => {
		message => q|Do not wrap text in editor?|,
        	lastUpdated => 1115148094,
	},

	'directionality' => {
		message => q|Text Direction|,
        	lastUpdated => 1115148847,
	},

	'left to right' => {
		message => q|Left to Right|,
        	lastUpdated => 1115148094,
	},

	'right to left' => {
		message => q|Right to Left|,
        	lastUpdated => 1115148094,
	},

	'toolbar location' => {
		message => q|Toolbar Location|,
        	lastUpdated => 1115148094,
	},

	'top' => {
		message => q|Top|,
        	lastUpdated => 1115148094,
	},

	'bottom' => {
		message => q|Bottom|,
        	lastUpdated => 1115148094,
	},

	'css file' => {
		message => q|CSS File|,
        	lastUpdated => 1115148094,
	},

	'enable context menu' => {
		message => q|Enable Context Menu|,
        	lastUpdated => 1115148094,
	},

	'search' => {
		message => q|Find|,
        	lastUpdated => 1115150778,
	},
	'replace' => {
		message => q|Find and Replace|,
        	lastUpdated => 1115150778,
	},
	'cut' => {
		message => q|Cut|,
        	lastUpdated => 1115150778,
	},
	'Copy' => {
		message => q|Copy|,
        	lastUpdated => 1224381734,
	},
	'paste' => {
		message => q|Paste|,
        	lastUpdated => 1115150778,
	},
	'pastetext' => {
		message => q|Paste as Plain Text|,
        	lastUpdated => 1115150778,
	},
	'pasteword' => {
		message => q|Paste from Word|,
        	lastUpdated => 1115150778,
	},
	'fullscreen' => {
		message => q|Fullscreen|,
        	lastUpdated => 1115150778,
	},
	'undo' => {
		message => q|Undo|,
        	lastUpdated => 1115150778,
	},
	'redo' => {
		message => q|Redo|,
        	lastUpdated => 1115150778,
	},
	'bold' => {
		message => q|Bold|,
        	lastUpdated => 1115150778,
	},
	'italic' => {
		message => q|Italic|,
        	lastUpdated => 1115150778,
	},
	'underline' => {
		message => q|Underline|,
        	lastUpdated => 1115150778,
	},
	'strikethrough' => {
		message => q|Strike Through|,
        	lastUpdated => 1115150778,
	},
	'justifyleft' => {
		message => q|Left Justified|,
        	lastUpdated => 1115150778,
	},
	'justifycenter' => {
		message => q|Centered|,
        	lastUpdated => 1115150778,
	},
	'justifyright' => {
		message => q|Right Justified|,
        	lastUpdated => 1115150778,
	},
	'justifyfull' => {
		message => q|Fully Justified|,
        	lastUpdated => 1115150778,
	},
	'bullist' => {
		message => q|Bulleted List|,
        	lastUpdated => 1115150778,
	},
	'numlist' => {
		message => q|Numbered List|,
        	lastUpdated => 1115150778,
	},
	'outdent' => {
		message => q|Outdent|,
        	lastUpdated => 1115150778,
	},
	'indent' => {
		message => q|Indent|,
        	lastUpdated => 1115150778,
	},
	'sub' => {
		message => q|Subscript|,
        	lastUpdated => 1115150778,
	},
	'sup' => {
		message => q|Superscript|,
        	lastUpdated => 1115150778,
	},
	'styleselect' => {
		message => q|Apply Style|,
        	lastUpdated => 1115150778,
	},
	'formatselect' => {
		message => q|Apply Format|,
        	lastUpdated => 1115150778,
	},
	'fontselect' => {
		message => q|Font|,
        	lastUpdated => 1115150778,
	},
	'fontsizeselect' => {
		message => q|Font Size|,
        	lastUpdated => 1115150778,
	},
	'forecolor' => {
		message => q|Foreground Color|,
        	lastUpdated => 1115150778,
	},
	'backcolor' => {
		message => q|Background Color|,
        	lastUpdated => 1115150778,
	},
	'link' => {
		message => q|Create Hyperlink|,
        	lastUpdated => 1115150778,
	},
	'pagetree' => {
		message => q|WebGUI Page Tree Link|,
        	lastUpdated => 1115150778,
	},
	'anchor' => {
		message => q|Anchor|,
        	lastUpdated => 1115150778,
	},
	'unlink' => {
		message => q|Unlink|,
        	lastUpdated => 1115150778,
	},
	'tablecontrols' => {
		message => q|Table Controls|,
        	lastUpdated => 1115150778,
	},
	'visualaid' => {
		message => q|Toggle Table Visual Aid|,
        	lastUpdated => 1115150778,
	},
	'hr' => {
		message => q|Insert Horizontal Rule|,
        	lastUpdated => 1115150778,
	},
	'advhr' => {
		message => q|Advanced Horizontal Rule|,
        	lastUpdated => 1115150778,
	},
	'inserttime' => {
		message => q|Insert Time|,
        	lastUpdated => 1115150778,
	},
	'insertdate' => {
		message => q|Insert Date|,
        	lastUpdated => 1115150778,
	},
	'image' => {
		message => q|Image|,
        	lastUpdated => 1115150778,
	},
	'insertImage' => {
		message => q|WebGUI Image|,
        	lastUpdated => 1115150778,
	},
    'media' => {
        message     => q|Embedded Media / Flash|,
        lastUpdated => 1206564394,
    },
	'charmap' => {
		message => q|Special Character|,
        	lastUpdated => 1115150778,
	},
	'collateral' => {
		message => q|WebGUI Macro|,
        	lastUpdated => 1115150778,
	},
	'emotions' => {
		message => q|Emoticons|,
        	lastUpdated => 1115150778,
	},
	'help' => {
		message => q|Help|,
        	lastUpdated => 1115150778,
	},
	'iespell' => {
		message => q|Spell Checker (IE Only)|,
        	lastUpdated => 1115150778,
	},
	'removeformat' => {
		message => q|Remove Formatting|,
        	lastUpdated => 1115150778,
	},
	'code' => {
		message => q|View/Edit Source|,
        	lastUpdated => 1115150778,
	},
	'cleanup' => {
		message => q|Clean Up Code|,
        	lastUpdated => 1115150778,
	},
	'save' => {
		message => q|Save / Submit|,
        	lastUpdated => 1115150778,
	},
	'preview' => {
		message => q|Preview|,
        	lastUpdated => 1115150778,
	},
	'print' => {
		message => q|Print|,
        	lastUpdated => 1115150778,
	},

	'button' => {
		message => q|Button|,
        	lastUpdated => 1115150778,
	},

	'row 1' => {
		message => q|Row 1|,
        	lastUpdated => 1115150778,
	},

	'row 2' => {
		message => q|Row 2|,
        	lastUpdated => 1115150778,
	},

	'row 3' => {
		message => q|Row 3|,
        	lastUpdated => 1115150778,
	},

	'rich edit edit config' => {
		message => q|Edit Rich Editor Configuration|,
        	lastUpdated => 1131398652,
	},

	'disable rich edit' => {
		message => q|Disable this Rich Editor?|,
        	lastUpdated => 1139957794,
	},

        'disable rich edit description' => {
                message => q|This is a master disable for the rich editor, and will turn off the Rich
		Edit across the entire site without any user intervention.|,
                lastUpdated => 1139958262,
        },

        'using rich edit description' => {
                message => q|Ask the user whether or not to use the Rich Editor on this form each time the form is accessed.|,
                lastUpdated => 1166844446,
        },

        'preformatted description' => {
                message => q|Normally, in HTML multiple spaces, tabs and carriage returns are considered as a single space.  If this
option is set to Yes, then all whitespace entered into the form will be preserved as is.|,
                lastUpdated => 1119584875,
        },

        'elements description' => {
                message => q|A list of HTML tags and their attributes that the rich editor will accept. All others will be stripped. To allow anything set it to *[*]. |,
                lastUpdated => 1119584875,
        },

        'editor height description' => {
                message => q|The height of the entire Rich Editor, including editing controls, in pixels|,
                lastUpdated => 1130878323,
        },

        'editor width description' => {
                message => q|The width of the entire Rich Editor, including editing controls, in pixels|,
                lastUpdated => 1130878326,
        },

        'source editor height description' => {
                message => q|The height of the area in the Rich Editor where the user can enter code, in pixels|,
                lastUpdated => 1130877981,
        },

        'source editor width description' => {
                message => q|The width of the area in the Rich Editor where the user can enter code, in pixels|,
                lastUpdated => 1130877982,
        },

        'use br description' => {
                message => q|Uses break tags &lt;BR&gt; instead of paragraph tags &lt;P&gt; when a new line is entered in the editor.|,
                lastUpdated => 1167187299,
        },

        'remove line breaks description' => {
                message => q|Removes line breaks from generated HTML.|,
                lastUpdated => 1119584875,
        },

        'no wrap description' => {
                message => q|Prevents word wrapping in the editor.|,
                lastUpdated => 1119584875,
        },

        'directionality description' => {
                message => q|Allows handling of languages that go from right to left or left to right.|,
                lastUpdated => 1119584875,
        },

        'toolbar location description' => {
                message => q|Set whether the toolbars should be placed above (top) or below (bottom) the form.|,
                lastUpdated => 1166844385,
        },

        'css file description' => {
                message => q|Specifies a CSS file used to style the contents of the editor.  If no CSS file is specified, a
		default will be used.|,
                lastUpdated => 1130878079,
        },

        'enable context menu description' => {
                message => q|Adds the context menu to toolbar row 1.|,
                lastUpdated => 1119584875,
        },

        'assetName' => {
                message => q|Rich Edit|,
                lastUpdated => 1128830747,
        },

	'Server Side Spell Checker' => {
		message => q|Server Side Spell Checker|,
		lastUpdated => 0,
	},

	'no dictionaries' => {
		message => q|No dictionaries are configured yet. Spellchecking will not be enabled before at least one is.|,
		lastUpdated => 0,
	},

    'inline popups' => {
        message => q|Inline Popups|,
        lastUpdated => 1206653834,
    },
    'inline popups description' => {
        message => q|Shows popups inline instead of in a popup browser window.|,
        lastUpdated => 1206653834,
    },

    'editForm allowMedia label' => {
        message     => q{Allow Media},
        lastUpdated => 0,
        context     => q{Label for asset property to allow multimedia items such as Flash},
    },

    'editForm allowMedia description' => {
        message     => q{Setting this to "yes" will allow Flash and other media to be embedded through
                        the rich editor. Note: Setting to "No" will not explicitly forbid Flash, but it
                        is not guaranteed to work.},
        lastUpdated => 0,
        context     => q{Description of asset property.},
    },

};

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_RichEdit.pm <==
package WebGUI::i18n::English::Asset_RichEdit;
use strict;

our $I18N = {

	'toolbar buttons' => {
		message => q|Toolbar Buttons|,
        	lastUpdated => 1115139736,
	},

	'toolbar buttons description' => {
		message => q|Shows which toolbar buttons will be used in which toolbars in the editor.  To remove a toolbar, deselect all buttons in that toolbar's column.  Note that other fields may add buttons to a toolbar row as well, such as Enable Context Menu.  Adding buttons also may not enable functionality.  You may also need to update the Valid Elements for this editor.|,
        	lastUpdated => 1228332284,
	},

	'using rich edit' => {
		message => q|Ask user about using rich edit?|,
        	lastUpdated => 1115139819,
	},

	'preformatted' => {
		message => q|Preserve whitespace as preformatted text?|,
        	lastUpdated => 1115139859,
	},

	'elements' => {
		message => q|Valid Elements|,
        	lastUpdated => 1115148094,
	},

	'elements subtext' => {
		message => q|<br /> Must appear on one line, no carriage returns, and in the format of tag1[attr1\|attr2],tag2[attr1].|,
        	lastUpdated => 1115148094,
	},

	'editor height' => {
		message => q|Editor Height|,
        	lastUpdated => 1115148094,
	},

	'editor width' => {
		message => q|Editor Width|,
        	lastUpdated => 1115148094,
	},

	'source editor height' => {
		message => q|Source Editor Height|,
        	lastUpdated => 1115148094,
	},

	'source editor width' => {
		message => q|Source Editor Width|,
        	lastUpdated => 1115148094,
	},

	'use br' => {
		message => q|Use &lt;br /&gt; instead of &lt;p&gt; on 'Enter'?|,
        	lastUpdated => 1115148632,
	},

	'remove line breaks' => {
		message => q|Remove line breaks from HTML?|,
        	lastUpdated => 1115148632,
	},

	'no wrap' => {
		message => q|Do not wrap text in editor?|,
        	lastUpdated => 1115148094,
	},

	'directionality' => {
		message => q|Text Direction|,
        	lastUpdated => 1115148847,
	},

	'left to right' => {
		message => q|Left to Right|,
        	lastUpdated => 1115148094,
	},

	'right to left' => {
		message => q|Right to Left|,
        	lastUpdated => 1115148094,
	},

	'toolbar location' => {
		message => q|Toolbar Location|,
        	lastUpdated => 1115148094,
	},

	'top' => {
		message => q|Top|,
        	lastUpdated => 1115148094,
	},

	'bottom' => {
		message => q|Bottom|,
        	lastUpdated => 1115148094,
	},

	'css file' => {
		message => q|CSS File|,
        	lastUpdated => 1115148094,
	},

	'enable context menu' => {
		message => q|Enable Context Menu|,
        	lastUpdated => 1115148094,
	},

	'search' => {
		message => q|Find|,
        	lastUpdated => 1115150778,
	},
	'replace' => {
		message => q|Find and Replace|,
        	lastUpdated => 1115150778,
	},
	'cut' => {
		message => q|Cut|,
        	lastUpdated => 1115150778,
	},
	'Copy' => {
		message => q|Copy|,
        	lastUpdated => 1224381734,
	},
	'paste' => {
		message => q|Paste|,
        	lastUpdated => 1115150778,
	},
	'pastetext' => {
		message => q|Paste as Plain Text|,
        	lastUpdated => 1115150778,
	},
	'pasteword' => {
		message => q|Paste from Word|,
        	lastUpdated => 1115150778,
	},
	'fullscreen' => {
		message => q|Fullscreen|,
        	lastUpdated => 1115150778,
	},
	'undo' => {
		message => q|Undo|,
        	lastUpdated => 1115150778,
	},
	'redo' => {
		message => q|Redo|,
        	lastUpdated => 1115150778,
	},
	'bold' => {
		message => q|Bold|,
        	lastUpdated => 1115150778,
	},
	'italic' => {
		message => q|Italic|,
        	lastUpdated => 1115150778,
	},
	'underline' => {
		message => q|Underline|,
        	lastUpdated => 1115150778,
	},
	'strikethrough' => {
		message => q|Strike Through|,
        	lastUpdated => 1115150778,
	},
	'justifyleft' => {
		message => q|Left Justified|,
        	lastUpdated => 1115150778,
	},
	'justifycenter' => {
		message => q|Centered|,
        	lastUpdated => 1115150778,
	},
	'justifyright' => {
		message => q|Right Justified|,
        	lastUpdated => 1115150778,
	},
	'justifyfull' => {
		message => q|Fully Justified|,
        	lastUpdated => 1115150778,
	},
	'bullist' => {
		message => q|Bulleted List|,
        	lastUpdated => 1115150778,
	},
	'numlist' => {
		message => q|Numbered List|,
        	lastUpdated => 1115150778,
	},
	'outdent' => {
		message => q|Outdent|,
        	lastUpdated => 1115150778,
	},
	'indent' => {
		message => q|Indent|,
        	lastUpdated => 1115150778,
	},
	'sub' => {
		message => q|Subscript|,
        	lastUpdated => 1115150778,
	},
	'sup' => {
		message => q|Superscript|,
        	lastUpdated => 1115150778,
	},
	'styleselect' => {
		message => q|Apply Style|,
        	lastUpdated => 1115150778,
	},
	'formatselect' => {
		message => q|Apply Format|,
        	lastUpdated => 1115150778,
	},
	'fontselect' => {
		message => q|Font|,
        	lastUpdated => 1115150778,
	},
	'fontsizeselect' => {
		message => q|Font Size|,
        	lastUpdated => 1115150778,
	},
	'forecolor' => {
		message => q|Foreground Color|,
        	lastUpdated => 1115150778,
	},
	'backcolor' => {
		message => q|Background Color|,
        	lastUpdated => 1115150778,
	},
	'link' => {
		message => q|Create Hyperlink|,
        	lastUpdated => 1115150778,
	},
	'pagetree' => {
		message => q|WebGUI Page Tree Link|,
        	lastUpdated => 1115150778,
	},
	'anchor' => {
		message => q|Anchor|,
        	lastUpdated => 1115150778,
	},
	'unlink' => {
		message => q|Unlink|,
        	lastUpdated => 1115150778,
	},
	'tablecontrols' => {
		message => q|Table Controls|,
        	lastUpdated => 1115150778,
	},
	'visualaid' => {
		message => q|Toggle Table Visual Aid|,
        	lastUpdated => 1115150778,
	},
	'hr' => {
		message => q|Insert Horizontal Rule|,
        	lastUpdated => 1115150778,
	},
	'advhr' => {
		message => q|Advanced Horizontal Rule|,
        	lastUpdated => 1115150778,
	},
	'inserttime' => {
		message => q|Insert Time|,
        	lastUpdated => 1115150778,
	},
	'insertdate' => {
		message => q|Insert Date|,
        	lastUpdated => 1115150778,
	},
	'image' => {
		message => q|Image|,
        	lastUpdated => 1115150778,
	},
	'insertImage' => {
		message => q|WebGUI Image|,
        	lastUpdated => 1115150778,
	},
    'media' => {
        message     => q|Embedded Media / Flash|,
        lastUpdated => 1206564394,
    },
	'charmap' => {
		message => q|Special Character|,
        	lastUpdated => 1115150778,
	},
	'collateral' => {
		message => q|WebGUI Macro|,
        	lastUpdated => 1115150778,
	},
	'emotions' => {
		message => q|Emoticons|,
        	lastUpdated => 1115150778,
	},
	'help' => {
		message => q|Help|,
        	lastUpdated => 1115150778,
	},
	'iespell' => {
		message => q|Spell Checker (IE Only)|,
        	lastUpdated => 1115150778,
	},
	'removeformat' => {
		message => q|Remove Formatting|,
        	lastUpdated => 1115150778,
	},
	'code' => {
		message => q|View/Edit Source|,
        	lastUpdated => 1115150778,
	},
	'cleanup' => {
		message => q|Clean Up Code|,
        	lastUpdated => 1115150778,
	},
	'save' => {
		message => q|Save / Submit|,
        	lastUpdated => 1115150778,
	},
	'preview' => {
		message => q|Preview|,
        	lastUpdated => 1115150778,
	},
	'print' => {
		message => q|Print|,
        	lastUpdated => 1115150778,
	},

	'button' => {
		message => q|Button|,
        	lastUpdated => 1115150778,
	},

	'row 1' => {
		message => q|Row 1|,
        	lastUpdated => 1115150778,
	},

	'row 2' => {
		message => q|Row 2|,
        	lastUpdated => 1115150778,
	},

	'row 3' => {
		message => q|Row 3|,
        	lastUpdated => 1115150778,
	},

	'rich edit edit config' => {
		message => q|Edit Rich Editor Configuration|,
        	lastUpdated => 1131398652,
	},

	'disable rich edit' => {
		message => q|Disable this Rich Editor?|,
        	lastUpdated => 1139957794,
	},

        'disable rich edit description' => {
                message => q|This is a master disable for the rich editor, and will turn off the Rich
		Edit across the entire site without any user intervention.|,
                lastUpdated => 1139958262,
        },

        'using rich edit description' => {
                message => q|Ask the user whether or not to use the Rich Editor on this form each time the form is accessed.|,
                lastUpdated => 1166844446,
        },

        'preformatted description' => {
                message => q|Normally, in HTML multiple spaces, tabs and carriage returns are considered as a single space.  If this
option is set to Yes, then all whitespace entered into the form will be preserved as is.|,
                lastUpdated => 1119584875,
        },

        'elements description' => {
                message => q|A list of HTML tags and their attributes that the rich editor will accept. All others will be stripped. To allow anything set it to *[*]. |,
                lastUpdated => 1119584875,
        },

        'editor height description' => {
                message => q|The height of the entire Rich Editor, including editing controls, in pixels|,
                lastUpdated => 1130878323,
        },

        'editor width description' => {
                message => q|The width of the entire Rich Editor, including editing controls, in pixels|,
                lastUpdated => 1130878326,
        },

        'source editor height description' => {
                message => q|The height of the area in the Rich Editor where the user can enter code, in pixels|,
                lastUpdated => 1130877981,
        },

        'source editor width description' => {
                message => q|The width of the area in the Rich Editor where the user can enter code, in pixels|,
                lastUpdated => 1130877982,
        },

        'use br description' => {
                message => q|Uses break tags &lt;BR&gt; instead of paragraph tags &lt;P&gt; when a new line is entered in the editor.|,
                lastUpdated => 1167187299,
        },

        'remove line breaks description' => {
                message => q|Removes line breaks from generated HTML.|,
                lastUpdated => 1119584875,
        },

        'no wrap description' => {
                message => q|Prevents word wrapping in the editor.|,
                lastUpdated => 1119584875,
        },

        'directionality description' => {
                message => q|Allows handling of languages that go from right to left or left to right.|,
                lastUpdated => 1119584875,
        },

        'toolbar location description' => {
                message => q|Set whether the toolbars should be placed above (top) or below (bottom) the form.|,
                lastUpdated => 1166844385,
        },

        'css file description' => {
                message => q|Specifies a CSS file used to style the contents of the editor.  If no CSS file is specified, a
		default will be used.|,
                lastUpdated => 1130878079,
        },

        'enable context menu description' => {
                message => q|Adds the context menu to toolbar row 1.|,
                lastUpdated => 1119584875,
        },

        'assetName' => {
                message => q|Rich Edit|,
                lastUpdated => 1128830747,
        },

	'Server Side Spell Checker' => {
		message => q|Server Side Spell Checker|,
		lastUpdated => 0,
	},

	'no dictionaries' => {
		message => q|No dictionaries are configured yet. Spellchecking will not be enabled before at least one is.|,
		lastUpdated => 0,
	},

    'inline popups' => {
        message => q|Inline Popups|,
        lastUpdated => 1206653834,
    },
    'inline popups description' => {
        message => q|Shows popups inline instead of in a popup browser window.|,
        lastUpdated => 1206653834,
    },

    'Toggle editor' => {
        message     => q{Toggle editor},
        lastUpdated => 0,
        context     => q{Toggle, to switch between on and off},
    },

    'editForm allowMedia label' => {
        message     => q{Allow Media},
        lastUpdated => 0,
        context     => q{Label for asset property to allow multimedia items such as Flash},
    },

    'editForm allowMedia description' => {
        message     => q{Setting this to "yes" will allow Flash and other media to be embedded through
                        the rich editor. Note: Setting to "No" will not explicitly forbid Flash, but it
                        is not guaranteed to work.},
        lastUpdated => 0,
        context     => q{Description of asset property.},
    },

};

1;
